@@ -34,13 +34,9 @@
 #include "zrtp_pbx.h"
 #include "zrtp_legal.h"
 #include "zrtp_version.h"
-#include "zrtp_cache.h"
-#include "zrtp_cache_file.h"
+#include "zrtp_iface_cache.h"
 #include "zrtp_ec.h"
 
-#if defined ZRTP_HAVE_SQLITE
-#include "zrtp_cache_db.h"
-#endif
 
 
 /**
@@ -152,9 +148,6 @@ typedef char zrtp_client_id_t[16];
  */
 typedef struct zrtp_config_t
 {	
-	/** @brief local endpoint  ZID */
-	zrtp_zid_t 				zid;
-
 	/** @brief Symbolic client identifier */
 	zrtp_client_id_t		client_id;
 	
@@ -167,15 +160,19 @@ typedef struct zrtp_config_t
 	/** @brief Set of interfaces required to operate with libzrtp */
 	zrtp_callback_t			cb;
 
-	/** Define type of zrtp cache implementation to use. Default is ZRTP_CACHE_FILE. */
-	zrtp_cache_type_t		cache_type;
+	/** @brief Path to zrtp cache file (set if you use built-in realization) */
+	zrtp_string256_t		def_cache_path;
 
-	/** ZRTP file-based cache configuration, used if \c cache_type if ZRTP_CACHE_FILE */
-	zrtp_cache_file_config_t cache_file_cfg;
-#if defined ZRTP_HAVE_SQLITE
-	/** ZRTP DB-based cache configuration, used if \c cache_type if ZRTP_CACHE_SQLITE */
-	zrtp_cache_db_config_t cache_db_cfg;
-#endif
+	/**
+	 * @brief Flush the cache automatically
+	 * Set to 1 if you want libzrtp to flush the cache to the persistent storage
+	 * right after it is modified. If cache_auto_store is 0, libzrtp will flush
+	 * the cache on going down only and the app is responsible for storing the
+	 * cache in unexpected situations. Enabled by default.
+	 *
+	 * @sa zrtp_def_cache_store()
+	 */
+	unsigned				cache_auto_store;
 } zrtp_config_t;
 
 /**
@@ -463,6 +460,7 @@ zrtp_status_t zrtp_down(zrtp_global_t* zrtp);
  * \param zrtp - global libzrtp context;
  * \param profile - the session configuration profile. If value of this parameter is NULL, default 
  *     profile will be used. NULL profile usage is equivalent to calling zrtp_profile_defaults().
+ * \param zid - ZRTP peer identificator.  
  * \param role - identifies if the endpoint was the signaling initiator of the call. Used to 
  *    provide Passive Mode options to the developer. If your application doesn't control signaling 
  *    or you don't want to support Passive Mode features - set it to ZRTP_SIGNALING_ROLE_UNKNOWN.
@@ -474,6 +472,7 @@ zrtp_status_t zrtp_down(zrtp_global_t* zrtp);
  */
 zrtp_status_t zrtp_session_init( zrtp_global_t* zrtp,
 								 zrtp_profile_t* profile,
+								 zrtp_zid_t zid,
 								 zrtp_signaling_role_t role,
 								 zrtp_session_t **session);
 /**
