@@ -19,7 +19,6 @@
 #include "zrtp_legal.h"
 #include "zrtp_string.h"
 #include "zrtp_protocol.h"
-#include "zrtp_cache.h"
 
 
 /**
@@ -181,6 +180,40 @@ struct zrtp_profile_t
 	uint8_t				hash_schemes[ZRTP_MAX_COMP_COUNT+1];
 };
 
+/**
+ * \brief Shared secret structure
+ * \ingroup zrtp_iface_cache
+ *
+ * This structure stores ZRTP shared secret values used in the protocol.
+ */
+struct zrtp_shared_secret_t
+{
+    /** \brief ZRTP secret value */
+    zrtp_string64_t			value;        
+
+	/**
+	 * \brief last usage time-stamp in seconds.
+	 *
+	 * Library updates this value on generation of the new value based on previous one.
+	 */
+	uint32_t				lastused_at;
+
+	/**
+	 * \brief TTL value in seconds.
+	 *
+	 * Available for reading after the Hello exchange. Updated on switching to Secure state.
+	 */
+	uint32_t				ttl;
+	
+	/**
+     * \brief Loaded secret flag.
+     *
+     * When the flag is set (= 1), the secret has been loaded from the cache. Otherwise the secret 
+     * has been generated.
+     * \warning For internal use only. Don't modify this flag in the application.
+     */
+    uint8_t					_cachedflag;	
+};
 
 /**
  * \brief Lists MitM roles on PBX call transferring
@@ -311,13 +344,13 @@ typedef enum zrtp_statemachine_type_t
  */
 struct zrtp_global_t
 {
-	zrtp_string16_t			zid;				/** local ZID */
 	uint32_t				lic_mode;			/** ZRTP license mode. */
     zrtp_string16_t			client_id;			/** Local ZRTP client ID. */
 	uint8_t					is_mitm;			/** Flags defines that the local endpoint acts as ZRTP MiTM. */
     MD_CTX					rand_ctx;			/** Hash context for entropy accumulation for the RNG unit. */
     uint8_t					rand_initialized;	/** RNG unit initialization flag. */
-	zrtp_cache_t			*cache;				/** ZRTP cache */
+	zrtp_string256_t		def_cache_path;		/** Full path to ZRTP cache file. */
+	unsigned				cache_auto_store;	/** Set when user wants libzrtp to flush the cache once it changed */
     zrtp_mutex_t*			rng_protector;		/** This object is used to protect the shared RNG hash zrtp#rand_ctx */
     struct BigNum			one;				/** This section provides static data for DH3K and DH4K components */
     struct BigNum			G;
@@ -769,6 +802,15 @@ struct zrtp_session_t
 	/*! Session unique identifier for debug purposes */
 	zrtp_id_t				id;
 	
+	/*!
+	 * \brief Local-side ZID
+	 * The unique 12-characters string that identifies the local ZRTP endpoint.
+	 * It must be generated by the user application on installation and used
+	 * permanently for every ZRTP session. This ID allows remote peers to
+	 * recognize this ZRTP endpoint.
+	 */	
+	zrtp_string16_t			zid;
+	
 	/*!
 	 * \brief Remote-side ZID
 	 * Extracted from the Hello packet of the very first ZRTP stream. Uniquely
